Contributing to pyAFQ
~~~~~~~~~~~~~~~~~~~~~

pyAFQ is an open-source software project. This means that you are welcome
to use it (see `LICENSE <https://github.com/yeatmanlab/pyAFQ/blob/master/LICENSE>`_ for details).

It also means that we welcome contributions from developers outside of our
research collaboration and we will credit these contributions appropriately.

Detailed guidelines for contribution are available `here <https://github.com/yeatmanlab/pyAFQ/blob/master/.github/CONTRIBUTING.md>`_.
